@@ -316,6 +316,10 @@ def ground_loss(
         return ground_loss_from_beam(beam, deg_step)
 
     elif str(filename).startswith(":"):
+        if band is None:
+            raise ValueError(
+                f"For non-absolute path {filename}, you must provide 'band'."
+            )
         if str(filename) == ":":
             # Use the built-in loss files
             fl = "ground"
